@@ -18,9 +18,9 @@
 ;;; conference.scm should be automatically loaded by init.scm
 ;;; usage:
 ;;; To start a conference with rms, thomas and roland
-;;;  ?eval (cf-start '(rms thomas roland))
+;;;  /eval (cf-start '(rms thomas roland))
 ;;; To end the conference
-;;;  ?eval (cf-end)
+;;;  /eval (cf-end)
 
 (if (defined? 'conference-group)
     '()
@@ -96,31 +96,31 @@
 
 ;;; Dynamic command support
 (fh-register-command!
- '("?vconf-start"
-   "?vconf-start CONF-BUDDY-LIST\n\t- create a virtual conference with given CONF-BUDDY-LIST"))
+ '("/vconf-start"
+   "/vconf-start CONF-BUDDY-LIST\n\t- create a virtual conference with given CONF-BUDDY-LIST"))
 
-(define (?vconf-start args-list)
+(define (/vconf-start args-list)
   (set! args-list (list->strlist args-list))
   (if (> (length args-list) 0)
       (begin
 	(cf-start args-list)
-	(fh-register-command! '("?vconf-end" "?vconf-end\n\t- close the virtual conference"))
-	(fh-register-command! '("?vconf-who" "?vconf-who\n\t- virtual conference members"))
-	(fh-unregister-command! "?vconf-start"))
+	(fh-register-command! '("/vconf-end" "/vconf-end\n\t- close the virtual conference"))
+	(fh-register-command! '("/vconf-who" "/vconf-who\n\t- virtual conference members"))
+	(fh-unregister-command! "/vconf-start"))
       (begin
-	(display "?vconf-start: wrong number of arguments")
+	(display "/vconf-start: wrong number of arguments")
 	(newline)
-	(display "usage: ?vconf-start userlist")
+	(display "usage: /vconf-start userlist")
 	(newline))))
 
-(define (?vconf-end args-list)
+(define (/vconf-end args-list)
   (cf-end)
-  (fh-unregister-command! "?vconf-end")
-  (fh-unregister-command! "?vconf-who")
+  (fh-unregister-command! "/vconf-end")
+  (fh-unregister-command! "/vconf-who")
   (fh-register-command!
-   '("?vconf-start"
-     "?vconf-start CONF-BUDDY-LIST\n\t- create a virtual conference with given CONF-BUDDY-LIST")))
+   '("/vconf-start"
+     "/vconf-start CONF-BUDDY-LIST\n\t- create a virtual conference with given CONF-BUDDY-LIST")))
 
 
-(define (?vconf-who args-list)
+(define (/vconf-who args-list)
   (conference-who conference-group))
