@@ -57,7 +57,7 @@ char * autocomplete_buddy_regex =
 "^\\ *\\/("
 		
 /* commands which accept 1st arg as buddy */
-"send|send\\-file|ignore|unignore|add|remove|reject|color\\-buddy|ping|buzz|forward|vconf\\-start|xmessage|freehoo|morse\\-send|"
+"send|send\\-file|ignore|unignore|add|remove|reject|color\\-buddy|ping|buzz|forward|vconf\\-start|xmessage|freehoo|morse\\-send|history|"
 		
 /* commands which accpet 1st arg and beyond as buddies */
 "(forward|vconf\\-start)\\ +[a-zA-Z0-9_\\-\\ ]*|" 
@@ -105,7 +105,7 @@ char * autocomplete_file_regex =
 
 char * autocomplete_cmd_regex = 		
 /* still in first word or no words yet*/
-"^\\ *\\/?[a-zA-Z0-9_\\-]*$" ;
+"^\\ *(\\?|\\/)?[a-zA-Z0-9_\\-]*$" ;
 
 extern YList *conferences;
 
@@ -280,6 +280,18 @@ command_generator (const char *text, int state)
     complete_file = 0,
     complete_dict = 0,
     complete_cmd = 0; // flags because regex is expensive
+  char *qu = rl_line_buffer;
+
+  while(*qu && (*qu == ' '))
+      qu++;
+  if(*qu == '?') *qu = '/';
+
+  qu = (char *) text;
+  
+  while(*qu && (*qu == ' '))
+      qu++;
+  if(*qu == '?') *qu = '/';
+
 
   if (!state)
     {
@@ -482,7 +494,8 @@ syntax_error (void)
 void
 interpreter (char *line)
 {
-  char *command, *dynamic_command;
+  char *command, *dynamic_command, *history_line;
+  char *qu = line;
   int i = 0;
   
   set_auto_insert_mode (1);
@@ -493,6 +506,10 @@ interpreter (char *line)
       return;
     }
 
+  while (*qu && *qu == ' ') qu++;
+
+  if (*qu == '?') *qu = '/';
+  
   line = stripwhite (line);
   
   if (strlen (line) == 0)
@@ -513,12 +530,25 @@ interpreter (char *line)
       else
 	recv_new = 1;
       return;
+
+    }
+
+  /* Preverse history before extracting the command out of it. We need
+  it to add_history later on. -- Anand Babu <ab@gnu.org.in> */
+  history_line = strdup (line);
+  command = get_token (&line);
+
+  /* This is not a command. Ignore all empty messages */
+  if (command[0] != '?' && command[0] != '/' &&
+      (!line || (line && *line) == 0))
+    {
+      free (history_line);
+      return;
     }
   
-  add_history (line);
-  
-  command = get_token (&line);
-  
+  add_history (history_line);
+  free (history_line);
+    
   /*  if (line)
       line = stripwhite (line);
   */
