@@ -681,8 +681,8 @@ ext_yahoo_contact_added (int id, char *myid, char *who, char *msg)
   char buf[1024];
 
   PRINTF_MESSAGE ("%s has added you to their contact list.\n", who);
-  PRINTF_MESSAGE ("Use \"?add %s\" to add %s to your contact list\n", who, who);
-  PRINTF_MESSAGE ("or Use \"?reject %s [MSG]\" to reject %s.\n", who, who);
+  PRINTF_MESSAGE ("Use \"/add %s\" to add %s to your contact list\n", who, who);
+  PRINTF_MESSAGE ("or Use \"/reject %s [MSG]\" to reject %s.\n", who, who);
 
   if(msg)
     strcpy (buf, msg);
@@ -1382,6 +1382,8 @@ void
 ext_yahoo_got_file (int id, char *who, char *url, long expires, char *msg,
 		    char *fname, unsigned long fesize)
 {
+  get_file_geturl_data_t data;
+
   if (msg && msg[0])
     {
       PRINTF_MESSAGE ("[%s] has sent a file [%s] with mesg [%s] (%lu bytes)\n", who, fname, msg,fesize);
@@ -1391,8 +1393,6 @@ ext_yahoo_got_file (int id, char *who, char *url, long expires, char *msg,
       PRINTF_MESSAGE ("[%s] has sent a file [%s] (%lu bytes)\n", who, fname,fesize);
     }
 
-
-    get_file_geturl_data_t data;
     data.who = who;
     data.url = url;
     data.fname = fname;
